<?php

declare(strict_types=1);

namespace Drupal\Tests\acquia_dam\Kernel;

use Drupal\media\Entity\MediaType;
use Drupal\media_library\MediaLibraryState;

/**
 * @coversDefaultClass \Drupal\acquia_dam\AssetLibraryBuilder
 * @group acquia_dam
 */
final class AssetLibraryBuilderTest extends AcquiaDamKernelTestBase {

  /**
   * Tests the source menu when there is one allowed media type.
   *
   * @covers ::addSourceMenu
   */
  public function testWhenOneAllowedMediaType(): void {
    $dam_image_type = $this->createImageMediaType();
    $sut = $this->container->get('acquia_dam.asset_library_builder');
    $state = MediaLibraryState::create(
      'editor',
      [$dam_image_type->id()],
      $dam_image_type->id(),
      1,
      []
    );
    $state->set('source', 'acquia_dam');
    $state->set('hash', $state->getHash());
    $build = $sut->addSourceMenu($state, 'acquia_dam');
    self::assertEquals([], $build['menu']);
  }

  /**
   * Tests the source menu when two allowed types, different sources.
   *
   * @covers ::addSourceMenu
   */
  public function testSourceMenu(): void {
    $dam_image_type = $this->createImageMediaType();
    $core_image_type = MediaType::create([
      'id' => strtolower($this->randomMachineName()),
      'label' => $this->randomString(),
      'source' => 'image',
    ]);
    $sut = $this->container->get('acquia_dam.asset_library_builder');
    $state = MediaLibraryState::create(
      'editor',
      [$dam_image_type->id(), $core_image_type->id()],
      $dam_image_type->id(),
      1,
    );
    $state->set('source', 'acquia_dam');
    $state->set('hash', $state->getHash());
    $build = $sut->addSourceMenu($state, 'acquia_dam');
    self::assertNotEquals([], $build['menu']);
    self::assertArrayHasKey('field', $build['menu']);
    self::assertArrayHasKey('link', $build['menu']);
    self::assertCount(1, $build['menu']['link']['#links']);
    $this->render($build);
    $this->assertNoEscaped($core_image_type->label());
    $this->assertEscaped($dam_image_type->label());
  }

}
